module.exports = defineTest({
	description: 'use of arguments is treated as a side-effect',
	options: { output: { name: 'myBundle' } }
});
